summaryrefslogtreecommitdiffstats
path: root/webkit/glue/plugins/plugin_list.h
diff options
context:
space:
mode:
authormpcomplete@chromium.org <mpcomplete@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-09-21 22:05:45 +0000
committermpcomplete@chromium.org <mpcomplete@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-09-21 22:05:45 +0000
commitb78e168b1640e456e1fc5a1ca8956a4a50c7df94 (patch)
treecbadab016871c254617ec26ab2d4c6987033b1c4 /webkit/glue/plugins/plugin_list.h
parenta66e24c34a22a4a183b91ad80d74e896a4f4db5f (diff)
downloadchromium_src-b78e168b1640e456e1fc5a1ca8956a4a50c7df94.zip
chromium_src-b78e168b1640e456e1fc5a1ca8956a4a50c7df94.tar.gz
chromium_src-b78e168b1640e456e1fc5a1ca8956a4a50c7df94.tar.bz2
Update renderer plugin cache when we load/unload extensions with plugins.
BUG=12306 TEST=Load and unload extensions that contain plugins and visit pages that use them. Also covered by tests. Review URL: http://codereview.chromium.org/201111 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@26748 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'webkit/glue/plugins/plugin_list.h')
-rw-r--r--webkit/glue/plugins/plugin_list.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/webkit/glue/plugins/plugin_list.h b/webkit/glue/plugins/plugin_list.h
index 7fc2b58..ddb30cf 100644
--- a/webkit/glue/plugins/plugin_list.h
+++ b/webkit/glue/plugins/plugin_list.h
@@ -80,9 +80,10 @@ class PluginList {
// plugins.
void ResetPluginsLoaded();
// Add an extra plugin to load when we actually do the loading. Must be
// called before the plugins have been loaded.
void AddExtraPluginPath(const FilePath& plugin_path);
+ void RemoveExtraPluginPath(const FilePath& plugin_path);
// Same as above, but specifies a directory in which to search for plugins.
void AddExtraPluginDir(const FilePath& plugin_dir);
@@ -80,9 +80,10 @@ class PluginList {
// plugins.
void ResetPluginsLoaded();
- // Add an extra plugin to load when we actually do the loading. Must be
- // called before the plugins have been loaded.
+ // Add/Remove an extra plugin to load when we actually do the loading. Must
+ // be called before the plugins have been loaded.
void AddExtraPluginPath(const FilePath& plugin_path);